package com.danikula.videocache;

import d.a.a.a.a;
import java.lang.Thread;
import java.util.concurrent.atomic.AtomicInteger;

public class ProxyCache {
    private static final int MAX_READ_SOURCE_ATTEMPTS = 1;
    private final Cache cache;
    private volatile int percentsAvailable = -1;
    private final AtomicInteger readSourceErrorsCount;
    private final Source source;
    private volatile Thread sourceReaderThread;
    private final Object stopLock = new Object();
    private volatile boolean stopped;
    private final Object wc = new Object();

    public class SourceReaderRunnable implements Runnable {
        private SourceReaderRunnable() {
        }

        public void run() {
            ProxyCache.this.readSource();
        }
    }

    public ProxyCache(Source source2, Cache cache2) {
        this.source = (Source) Preconditions.checkNotNull(source2);
        this.cache = (Cache) Preconditions.checkNotNull(cache2);
        this.readSourceErrorsCount = new AtomicInteger();
    }

    private void checkReadSourceErrorsCount() {
        int i2 = this.readSourceErrorsCount.get();
        if (i2 >= 1) {
            this.readSourceErrorsCount.set(0);
            throw new ProxyCacheException(a.m("Error reading source ", i2, " times"));
        }
    }

    private void closeSource() {
        try {
            this.source.close();
        } catch (ProxyCacheException e2) {
            StringBuilder B = a.B("Error closing source ");
            B.append(this.source);
            onError(new ProxyCacheException(B.toString(), e2));
        }
    }

    private boolean isStopped() {
        return Thread.currentThread().isInterrupted() || this.stopped;
    }

    private void notifyNewCacheDataAvailable(long j2, long j3) {
        onCacheAvailable(j2, j3);
        synchronized (this.wc) {
            this.wc.notifyAll();
        }
    }

    private void onSourceRead() {
        this.percentsAvailable = 100;
        onCachePercentsAvailableChanged(this.percentsAvailable);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void readSource() {
        long j2 = -1;
        long j3 = 0;
        try {
            j3 = this.cache.available();
            this.source.open(j3);
            j2 = this.source.length();
            byte[] bArr = new byte[8192];
            while (true) {
                int read = this.source.read(bArr);
                if (read == -1) {
                    tryComplete();
                    onSourceRead();
                    break;
                }
                synchronized (this.stopLock) {
                    if (isStopped()) {
                        closeSource();
                        notifyNewCacheDataAvailable(j3, j2);
                        return;
                    }
                    this.cache.append(bArr, read);
                }
                j3 += (long) read;
                notifyNewCacheDataAvailable(j3, j2);
            }
        } catch (Throwable th) {
            closeSource();
            notifyNewCacheDataAvailable(0, -1);
            throw th;
        }
        closeSource();
        notifyNewCacheDataAvailable(j3, j2);
    }

    private synchronized void readSourceAsync() {
        boolean z = (this.sourceReaderThread == null || this.sourceReaderThread.getState() == Thread.State.TERMINATED) ? false : true;
        if (!this.stopped && !this.cache.isCompleted() && !z) {
            SourceReaderRunnable sourceReaderRunnable = new SourceReaderRunnable();
            this.sourceReaderThread = new Thread(sourceReaderRunnable, "Source reader for " + this.source);
            this.sourceReaderThread.start();
        }
    }

    private void tryComplete() {
        synchronized (this.stopLock) {
            if (!isStopped() && this.cache.available() == this.source.length()) {
                this.cache.complete();
            }
        }
    }

    private void waitForSourceData() {
        synchronized (this.wc) {
            try {
                this.wc.wait(1000);
            } catch (InterruptedException e2) {
                throw new ProxyCacheException("Waiting source data is interrupted!", e2);
            } catch (Throwable th) {
                throw th;
            }
        }
    }

    public void onCacheAvailable(long j2, long j3) {
        boolean z = true;
        int i2 = (j3 > 0 ? 1 : (j3 == 0 ? 0 : -1));
        int i3 = i2 == 0 ? 100 : (int) ((((float) j2) / ((float) j3)) * 100.0f);
        boolean z2 = i3 != this.percentsAvailable;
        if (i2 < 0) {
            z = false;
        }
        if (z && z2) {
            onCachePercentsAvailableChanged(i3);
        }
        this.percentsAvailable = i3;
    }

    public void onCachePercentsAvailableChanged(int i2) {
    }

    public final void onError(Throwable th) {
        if (th instanceof InterruptedProxyCacheException) {
            HttpProxyCacheDebuger.printfLog("ProxyCache is interrupted");
        } else {
            HttpProxyCacheDebuger.printfError("ProxyCache error", th.getMessage());
        }
    }

    public int read(byte[] bArr, long j2, int i2) {
        ProxyCacheUtils.assertBuffer(bArr, j2, i2);
        while (!this.cache.isCompleted() && this.cache.available() < ((long) i2) + j2 && !this.stopped) {
            readSourceAsync();
            waitForSourceData();
            checkReadSourceErrorsCount();
        }
        int read = this.cache.read(bArr, j2, i2);
        if (this.cache.isCompleted() && this.percentsAvailable != 100) {
            this.percentsAvailable = 100;
            onCachePercentsAvailableChanged(100);
        }
        return read;
    }

    public void shutdown() {
        synchronized (this.stopLock) {
            try {
                this.stopped = true;
                if (this.sourceReaderThread != null) {
                    this.sourceReaderThread.interrupt();
                }
                this.cache.close();
            } catch (ProxyCacheException e2) {
                onError(e2);
            }
        }
    }
}
