package okhttp3.internal.ws;

import d.a.a.a.a;
import java.io.EOFException;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import okio.Buffer;
import okio.BufferedSource;
import okio.ByteString;

public final class WebSocketReader {
    public boolean closed;
    public long frameBytesRead;
    public final FrameCallback frameCallback;
    public long frameLength;
    public final boolean isClient;
    public boolean isControlFrame;
    public boolean isFinalFrame;
    public boolean isMasked;
    public final byte[] maskBuffer = new byte[8192];
    public final byte[] maskKey = new byte[4];
    public int opcode;
    public final BufferedSource source;

    public interface FrameCallback {
        void onReadClose(int i2, String str);

        void onReadMessage(String str);

        void onReadMessage(ByteString byteString);

        void onReadPing(ByteString byteString);

        void onReadPong(ByteString byteString);
    }

    public WebSocketReader(boolean z, BufferedSource bufferedSource, FrameCallback frameCallback2) {
        Objects.requireNonNull(bufferedSource, "source == null");
        Objects.requireNonNull(frameCallback2, "frameCallback == null");
        this.isClient = z;
        this.source = bufferedSource;
        this.frameCallback = frameCallback2;
    }

    private void readControlFrame() {
        String str;
        Buffer buffer = new Buffer();
        long j2 = this.frameBytesRead;
        long j3 = this.frameLength;
        if (j2 < j3) {
            if (!this.isClient) {
                while (true) {
                    long j4 = this.frameBytesRead;
                    long j5 = this.frameLength;
                    if (j4 >= j5) {
                        break;
                    }
                    int read = this.source.read(this.maskBuffer, 0, (int) Math.min(j5 - j4, (long) this.maskBuffer.length));
                    if (read != -1) {
                        long j6 = (long) read;
                        WebSocketProtocol.toggleMask(this.maskBuffer, j6, this.maskKey, this.frameBytesRead);
                        buffer.write(this.maskBuffer, 0, read);
                        this.frameBytesRead += j6;
                    } else {
                        throw new EOFException();
                    }
                }
            } else {
                this.source.readFully(buffer, j3);
            }
        }
        switch (this.opcode) {
            case 8:
                short s = 1005;
                long size = buffer.size();
                if (size != 1) {
                    if (size != 0) {
                        s = buffer.readShort();
                        str = buffer.readUtf8();
                        String closeCodeExceptionMessage = WebSocketProtocol.closeCodeExceptionMessage(s);
                        if (closeCodeExceptionMessage != null) {
                            throw new ProtocolException(closeCodeExceptionMessage);
                        }
                    } else {
                        str = "";
                    }
                    this.frameCallback.onReadClose(s, str);
                    this.closed = true;
                    return;
                }
                throw new ProtocolException("Malformed close payload length of 1.");
            case 9:
                this.frameCallback.onReadPing(buffer.readByteString());
                return;
            case 10:
                this.frameCallback.onReadPong(buffer.readByteString());
                return;
            default:
                StringBuilder B = a.B("Unknown control opcode: ");
                B.append(Integer.toHexString(this.opcode));
                throw new ProtocolException(B.toString());
        }
    }

    /* JADX INFO: finally extract failed */
    private void readHeader() {
        if (!this.closed) {
            long timeoutNanos = this.source.timeout().timeoutNanos();
            this.source.timeout().clearTimeout();
            try {
                int readByte = this.source.readByte() & 255;
                this.source.timeout().timeout(timeoutNanos, TimeUnit.NANOSECONDS);
                this.opcode = readByte & 15;
                boolean z = true;
                boolean z2 = (readByte & 128) != 0;
                this.isFinalFrame = z2;
                boolean z3 = (readByte & 8) != 0;
                this.isControlFrame = z3;
                if (!z3 || z2) {
                    boolean z4 = (readByte & 64) != 0;
                    boolean z5 = (readByte & 32) != 0;
                    boolean z6 = (readByte & 16) != 0;
                    if (z4 || z5 || z6) {
                        throw new ProtocolException("Reserved flags are unsupported.");
                    }
                    int readByte2 = this.source.readByte() & 255;
                    if ((readByte2 & 128) == 0) {
                        z = false;
                    }
                    this.isMasked = z;
                    if (z == this.isClient) {
                        throw new ProtocolException(this.isClient ? "Server-sent frames must not be masked." : "Client-sent frames must be masked.");
                    }
                    long j2 = (long) (readByte2 & 127);
                    this.frameLength = j2;
                    if (j2 == 126) {
                        this.frameLength = ((long) this.source.readShort()) & WebSocketProtocol.PAYLOAD_SHORT_MAX;
                    } else if (j2 == 127) {
                        long readLong = this.source.readLong();
                        this.frameLength = readLong;
                        if (readLong < 0) {
                            StringBuilder B = a.B("Frame length 0x");
                            B.append(Long.toHexString(this.frameLength));
                            B.append(" > 0x7FFFFFFFFFFFFFFF");
                            throw new ProtocolException(B.toString());
                        }
                    }
                    this.frameBytesRead = 0;
                    if (this.isControlFrame && this.frameLength > 125) {
                        throw new ProtocolException("Control frame must be less than 125B.");
                    } else if (this.isMasked) {
                        this.source.readFully(this.maskKey);
                    }
                } else {
                    throw new ProtocolException("Control frames must be final.");
                }
            } catch (Throwable th) {
                this.source.timeout().timeout(timeoutNanos, TimeUnit.NANOSECONDS);
                throw th;
            }
        } else {
            throw new IOException("closed");
        }
    }

    private void readMessage(Buffer buffer) {
        long j2;
        while (!this.closed) {
            if (this.frameBytesRead == this.frameLength) {
                if (!this.isFinalFrame) {
                    readUntilNonControlFrame();
                    if (this.opcode != 0) {
                        StringBuilder B = a.B("Expected continuation opcode. Got: ");
                        B.append(Integer.toHexString(this.opcode));
                        throw new ProtocolException(B.toString());
                    } else if (this.isFinalFrame && this.frameLength == 0) {
                        return;
                    }
                } else {
                    return;
                }
            }
            long j3 = this.frameLength - this.frameBytesRead;
            if (this.isMasked) {
                j2 = (long) this.source.read(this.maskBuffer, 0, (int) Math.min(j3, (long) this.maskBuffer.length));
                if (j2 != -1) {
                    WebSocketProtocol.toggleMask(this.maskBuffer, j2, this.maskKey, this.frameBytesRead);
                    buffer.write(this.maskBuffer, 0, (int) j2);
                } else {
                    throw new EOFException();
                }
            } else {
                j2 = this.source.read(buffer, j3);
                if (j2 == -1) {
                    throw new EOFException();
                }
            }
            this.frameBytesRead += j2;
        }
        throw new IOException("closed");
    }

    private void readMessageFrame() {
        int i2 = this.opcode;
        if (i2 == 1 || i2 == 2) {
            Buffer buffer = new Buffer();
            readMessage(buffer);
            if (i2 == 1) {
                this.frameCallback.onReadMessage(buffer.readUtf8());
            } else {
                this.frameCallback.onReadMessage(buffer.readByteString());
            }
        } else {
            StringBuilder B = a.B("Unknown opcode: ");
            B.append(Integer.toHexString(i2));
            throw new ProtocolException(B.toString());
        }
    }

    public void processNextFrame() {
        readHeader();
        if (this.isControlFrame) {
            readControlFrame();
        } else {
            readMessageFrame();
        }
    }

    public void readUntilNonControlFrame() {
        while (!this.closed) {
            readHeader();
            if (this.isControlFrame) {
                readControlFrame();
            } else {
                return;
            }
        }
    }
}
